package com.mudu.quartz;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.mudu.entity.ASafeQyjcxx;
import com.mudu.entity.ASafeQyjcxxMdLog;
import com.mudu.service.ASafeQyjcxxMdLogService;
import com.mudu.service.ASafeQyjcxxService;
import com.mudu.service.ASafeWgcyService;
import com.mudu.service.impl.LoginService;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * 获取木渎新增企业定时任务
 *
 * @author wu
 * @since 2024/8/24 18:11
 */
@Transactional(rollbackFor = Exception.class)
@Configuration
@EnableScheduling
public class EntQuartz {

    @Resource
    private ASafeQyjcxxService qyjcxxService;

    @Resource
    private ASafeWgcyService wgcyService;

    @Resource
    private LoginService loginService;

    @Resource
    private ASafeQyjcxxMdLogService qyjcxxMdLogService;

    @Value("${addEntUrl}")
    private String addEntUrl;

    @Value("${findEntDelUrl}")
    private String findEntDelUrl;


    private String getToken() {
        return "Bearer " + loginService.getToken();
    }

    /**
     * 新增昨天木渎新增的企业
     */
    @Scheduled(cron = "0 30 00 * * ? ")
    public void addqyjcxxAndWgcy() {
        // 获取token
        String token = getToken();
        // 获取所有信息
        String res = HttpRequest.get(addEntUrl)
                .contentType("application/x-www-form-urlencoded;charset=UTF-8")
                .header("Authorization", token)
                .execute().body();
        JSONObject resObj = JSON.parseObject(res);
        String dataList = resObj.getString("data");
        if (StrUtil.isEmpty(dataList)) {
            return;
        }
        List<ASafeQyjcxx> qyjcxxList = JSON.parseArray(dataList, ASafeQyjcxx.class);
        for (ASafeQyjcxx x : qyjcxxList) {
            ASafeQyjcxx entity = qyjcxxService.findOneByqymcOrXybm(null, x.getTyshxybm());
            if (BeanUtil.isNotEmpty(entity)) {
                if (entity.getJlzt() == 0) {
                    qyjcxxService.updateJlztById(entity.getXxbh());
                    // 添加更新日志
                    ASafeQyjcxxMdLog qyjcxxMdLog = BeanUtil.copyProperties(entity, ASafeQyjcxxMdLog.class);
                    qyjcxxMdLog.setGxorxz(0);
                    qyjcxxMdLogService.save(qyjcxxMdLog);
                }
            } else {
                qyjcxxService.save(x);
                // 添加新增日志
                ASafeQyjcxxMdLog qyjcxxMdLog = BeanUtil.copyProperties(x, ASafeQyjcxxMdLog.class);
                qyjcxxMdLog.setGxorxz(0);
                qyjcxxMdLogService.save(qyjcxxMdLog);
            }
        }
//        List<ASafeWgcy> wgcyList = qyjcxxList.stream().map(ASafeQyjcxx::getASafeWgcy).collect(Collectors.toList());
//        wgcyService.saveBatch(wgcyList);
    }


    /**
     * 删除昨天木渎删除的企业
     */
    @Scheduled(cron = "0 30 00 * * ? ")
    public void findEntDel() {
        // 获取token
        String token = getToken();
        // 获取所有信息
        String res = HttpRequest.get(findEntDelUrl)
                .contentType("application/x-www-form-urlencoded;charset=UTF-8")
                .header("Authorization", token)
                .execute().body();
        JSONObject resObj = JSON.parseObject(res);
        String dataList = resObj.getString("data");
        if (StrUtil.isEmpty(dataList)) {
            return;
        }
        List<String> tyshxybmList = JSON.parseArray(dataList, String.class);
        if (CollectionUtil.isNotEmpty(tyshxybmList)) {
            qyjcxxService.updateByTyshxybm(tyshxybmList);
        }
    }
}
